==> cohesity_management_sdk-1.1.1.tar.gz: cohesity_management_sdk-1.1.1/cohesity_management_sdk/models/category_alert_metadata_enum.py <==
# -*- coding: utf-8 -*-
# Copyright 2019 Cohesity Inc.

class CategoryAlertMetadataEnum(object):

    """Implementation of the 'Category_AlertMetadata' enum.

    Specifies category of the alert type. Specifies the category of an Alert.
    kDisk - Alerts that are related to Disk. kNode - Alerts that are related
    to Node. kCluster - Alerts that are related to Cluster. kNodeHealth -
    Alerts that are related to Node Health. kClusterHealth - Alerts that are
    related to Cluster Health. kBackupRestore - Alerts that are related to
    Backup/Restore. kEncryption - Alerts that are related to Encryption.
    kArchivalRestore - Alerts that are related to Archival/Restore.
    kRemoteReplication - Alerts that are related to Remote Replication. kQuota
    - Alerts that are related to Quota. kLicense - Alerts that are related to
    License. kHeliosProActiveWellness - Alerts that are related to Helios
    ProActive Wellness. kHeliosAnalyticsJobs - Alerts that are related to
    Helios Analytics Jobs. kHeliosSignatureJobs - Alerts that are related to
    Helios Signature Jobs. kSecurity - Alerts that are related to Security.

    Attributes:
        KDISK: TODO: type description here.
        KNODE: TODO: type description here.
        KCLUSTER: TODO: type description here.
        KNODEHEALTH: TODO: type description here.
        KCLUSTERHEALTH: TODO: type description here.
        KBACKUPRESTORE: TODO: type description here.
        KENCRYPTION: TODO: type description here.
        KARCHIVALRESTORE: TODO: type description here.
        KREMOTEREPLICATION: TODO: type description here.
        KQUOTA: TODO: type description here.
        KLICENSE: TODO: type description here.
        KHELIOSPROACTIVEWELLNESS: TODO: type description here.
        KHELIOSANALYTICSJOBS: TODO: type description here.
        KHELIOSSIGNATUREJOBS: TODO: type description here.
        KSECURITY: TODO: type description here.

    """

    KDISK = 'kDisk'

    KNODE = 'kNode'

    KCLUSTER = 'kCluster'

    KNODEHEALTH = 'kNodeHealth'

    KCLUSTERHEALTH = 'kClusterHealth'

    KBACKUPRESTORE = 'kBackupRestore'

    KENCRYPTION = 'kEncryption'

    KARCHIVALRESTORE = 'kArchivalRestore'

    KREMOTEREPLICATION = 'kRemoteReplication'

    KQUOTA = 'kQuota'

    KLICENSE = 'kLicense'

    KHELIOSPROACTIVEWELLNESS = 'kHeliosProActiveWellness'

    KHELIOSANALYTICSJOBS = 'kHeliosAnalyticsJobs'

    KHELIOSSIGNATUREJOBS = 'kHeliosSignatureJobs'

    KSECURITY = 'kSecurity'

==> cohesity_management_sdk-1.1.3.tar.gz: cohesity_management_sdk-1.1.3/cohesity_management_sdk/models/category_alert_metadata_enum.py <==
# -*- coding: utf-8 -*-
# Copyright 2019 Cohesity Inc.

class CategoryAlertMetadataEnum(object):

    """Implementation of the 'Category_AlertMetadata' enum.

    Specifies category of the alert type.
    Specifies the category of an Alert.
    kDisk - Alerts that are related to Disk.
    kNode - Alerts that are related to Node.
    kCluster - Alerts that are related to Cluster.
    kNodeHealth - Alerts that are related to Node Health.
    kClusterHealth - Alerts that are related to Cluster Health.
    kBackupRestore - Alerts that are related to Backup/Restore.
    kEncryption - Alerts that are related to Encryption.
    kArchivalRestore - Alerts that are related to Archival/Restore.
    kRemoteReplication - Alerts that are related to Remote Replication.
    kQuota - Alerts that are related to Quota.
    kLicense - Alerts that are related to License.
    kHeliosProActiveWellness - Alerts that are related to Helios ProActive
    Wellness.
    kHeliosAnalyticsJobs - Alerts that are related to Helios Analytics Jobs.
    kHeliosSignatureJobs - Alerts that are related to Helios Signature Jobs.
    kSecurity - Alerts that are related to Security.

    Attributes:
        KDISK: TODO: type description here.
        KNODE: TODO: type description here.
        KCLUSTER: TODO: type description here.
        KNODEHEALTH: TODO: type description here.
        KCLUSTERHEALTH: TODO: type description here.
        KBACKUPRESTORE: TODO: type description here.
        KENCRYPTION: TODO: type description here.
        KARCHIVALRESTORE: TODO: type description here.
        KREMOTEREPLICATION: TODO: type description here.
        KQUOTA: TODO: type description here.
        KLICENSE: TODO: type description here.
        KHELIOSPROACTIVEWELLNESS: TODO: type description here.
        KHELIOSANALYTICSJOBS: TODO: type description here.
        KHELIOSSIGNATUREJOBS: TODO: type description here.
        KSECURITY: TODO: type description here.

    """

    KDISK = 'kDisk'

    KNODE = 'kNode'

    KCLUSTER = 'kCluster'

    KNODEHEALTH = 'kNodeHealth'

    KCLUSTERHEALTH = 'kClusterHealth'

    KBACKUPRESTORE = 'kBackupRestore'

    KENCRYPTION = 'kEncryption'

    KARCHIVALRESTORE = 'kArchivalRestore'

    KREMOTEREPLICATION = 'kRemoteReplication'

    KQUOTA = 'kQuota'

    KLICENSE = 'kLicense'

    KHELIOSPROACTIVEWELLNESS = 'kHeliosProActiveWellness'

    KHELIOSANALYTICSJOBS = 'kHeliosAnalyticsJobs'

    KHELIOSSIGNATUREJOBS = 'kHeliosSignatureJobs'

    KSECURITY = 'kSecurity'
